@@ -23,11 +23,12 @@ from hspylib.core.exception.exceptions import WidgetExecutionError
 from hspylib.core.tools.commons import sysout
 from hspylib.modules.cli.icons.font_awesome.widget_icons import WidgetIcons
 from hspylib.modules.cli.menu.extra.minput.minput import minput, MenuInput
+from hspylib.modules.cli.menu.menu_utils import MenuUtils
 
 
 class WidgetTimeCalc(Widget):
 
-    WIDGET_ICON = WidgetIcons.TCALC
+    WIDGET_ICON = WidgetIcons.CLOCK
     WIDGET_NAME = "TimeCalc"
     TOOLTIP = "Calculate time based operations."
     USAGE = "Usage: TimeCalc [-d|--decimal] <HH1:MM1[:SS1]> <+|-> <HH2:MM2[:SS2]>"
@@ -35,11 +36,11 @@ class WidgetTimeCalc(Widget):
 
     def __init__(self):
         super().__init__(
-            WidgetTimeCalc.WIDGET_ICON,
-            WidgetTimeCalc.WIDGET_NAME,
-            WidgetTimeCalc.TOOLTIP,
-            WidgetTimeCalc.USAGE,
-            WidgetTimeCalc.VERSION)
+            self.WIDGET_ICON,
+            self.WIDGET_NAME,
+            self.TOOLTIP,
+            self.USAGE,
+            self.VERSION)
 
         self.total_seconds = 0
         self.op = '+'
@@ -87,11 +88,14 @@ class WidgetTimeCalc(Widget):
         self.total_seconds, seconds = divmod(self.total_seconds, 60)
         hours, minutes = divmod(self.total_seconds, 60)
 
+        sysout('%HOM%%ED2%%MOD(0)%', end='')
         if self.decimal:
             sysout(f"{hours:02d}.{self._decimal(minutes):02d}.{self._decimal(seconds):02d}")
         else:
             sysout(f"{hours:02d}:{self._decimal(minutes):02d}:{self._decimal(seconds):02d}")
 
+        MenuUtils.wait_enter()
+
         return ret_val
 
     def cleanup(self):
