@@ -16,7 +16,7 @@
 
 from emoji.core import emojize
 
-from hspylib.core.enum.enumeration import Enumeration
+from hspylib.core.enums.enumeration import Enumeration
 
 
 def emj_print(emoji_str: str) -> None:
@@ -29,9 +29,9 @@ class Emoji(Enumeration):
         Full list of emojis can be found here:
           - https://unicode.org/emoji/charts/emoji-list.html
     """
-
+    
     def __str__(self) -> str:
         return str(self.value)
-
+    
     def placeholder(self) -> str:
         return f":{self.name}:"
