@@ -21,12 +21,14 @@ import termios
 import tty
 from typing import List, Optional, Tuple
 
-assert sys.stdin.isatty(), 'This module requires a terminal (TTY)'
+from hspylib.core.tools.commons import is_debugging
 
 
 def require_terminal():
     assert sys.stdin.isatty(), 'This module requires a terminal (TTY)'
 
+require_terminal()
+
 
 def screen_size() -> Optional[List[str]]:
     """Retrieve the size of the terminal"""
@@ -36,12 +38,11 @@ def screen_size() -> Optional[List[str]]:
     return None
 
 
+# Solution taken from:
+# https://stackoverflow.com/questions/46651602/determine-the-terminal-cursor-position-with-an-ansi-sequence-in-python-3
 def get_cursor_position() -> Optional[Tuple[int, int]]:
-    """ Get the terminal cursor position
-    Solution taken from:
-    - https://stackoverflow.com/questions/46651602/determine-the-terminal-cursor-position-with-an-ansi-sequence-in-python-3
-    """
-    if sys.stdout.isatty():
+    """ Get the terminal cursor position """
+    if sys.stdout.isatty() and not is_debugging():
         buf = ""
         stdin = sys.stdin.fileno()
         attrs = termios.tcgetattr(stdin)
