@@ -13,13 +13,14 @@
 
    Copyright 2021, HSPyLib team
 """
+from typing import Any
 
 from requests.structures import CaseInsensitiveDict
 
-from hspylib.core.enum.charset import Charset
-from hspylib.core.enum.content_type import ContentType
-from hspylib.core.enum.http_code import HttpCode
-from hspylib.core.enum.http_method import HttpMethod
+from hspylib.core.enums.charset import Charset
+from hspylib.core.enums.content_type import ContentType
+from hspylib.core.enums.http_code import HttpCode
+from hspylib.core.enums.http_method import HttpMethod
 from hspylib.modules.fetch.http_response import HttpResponse
 
 
@@ -33,18 +34,18 @@ class MockResponse(HttpResponse):
                  headers=None,
                  encoding: Charset = Charset.UTF_8,
                  content_type=ContentType.APPLICATION_JSON):
-
+        
         super().__init__(method, url, status_code, body, headers, encoding, content_type)
         self.parent = parent
         self.received_body = False
-
+    
     def then_return(self,
                     code: HttpCode,
                     body: str = None,
                     headers=None,
                     encoding: Charset = Charset.UTF_8,
-                    content_type=ContentType.APPLICATION_JSON):
-
+                    content_type=ContentType.APPLICATION_JSON) -> Any:
+        
         response = self.parent.mock(self.method, self.url)
         response.status_code = code
         response.body = body
@@ -54,12 +55,12 @@ class MockResponse(HttpResponse):
         if response.content_type:
             response.content_type.charset = encoding
         return self.parent
-
+    
     def then_return_with_received_body(self,
                                        code: HttpCode,
                                        headers: CaseInsensitiveDict = None,
                                        encoding: Charset = Charset.UTF_8,
-                                       content_type=ContentType.APPLICATION_JSON):
+                                       content_type=ContentType.APPLICATION_JSON) -> Any:
         response = self.parent.mock(self.method, self.url)
         response.received_body = True
         response.body = None
