@@ -19,7 +19,7 @@ from typing import Optional
 
 from requests.structures import CaseInsensitiveDict
 
-from hspylib.core.enum.http_method import HttpMethod
+from hspylib.core.enums.http_method import HttpMethod
 from hspylib.modules.fetch.fetch import fetch
 from hspylib.modules.fetch.http_response import HttpResponse
 
@@ -38,5 +38,5 @@ def rest_call(
     response = fetch(url=url, method=method, headers=all_headers, body=data)
     log.info('Response <=  Status: {}  Payload: {}'.format(
         response.status_code, response))
-
+    
     return response
